<script>import TimePicker from "./TimePicker.svelte";
import { createEventDispatcher, onDestroy } from "svelte";
const dispatch = createEventDispatcher();
const close = () => dispatch("close");
export let options = { zIndex: 0 };
export let date = /* @__PURE__ */ new Date();
let modal;
let zIndexStyle = "z-index:" + options.zIndex + ";";
const handleCancel = (event) => {
  close();
  dispatch("cancel", event.detail);
};
const handleKeydown = (event) => {
  if (event.key === "Escape") {
    close();
    return;
  }
  if (event.key === "Tab") {
    const nodes = modal.querySelectorAll("*");
    const tabbable = Array.from(nodes).filter((n) => n.tabIndex >= 0);
    let index = tabbable.indexOf(document.activeElement);
    if (index === -1 && event.shiftKey)
      index = 0;
    index += tabbable.length + (event.shiftKey ? -1 : 1);
    index %= tabbable.length;
    const element = tabbable[index];
    element.focus();
    event.preventDefault();
  }
};
const handleOK = (event) => {
  close();
  dispatch("ok", event.detail);
};
const previouslyFocused = typeof document !== "undefined" && document.activeElement;
if (previouslyFocused) {
  const previouslyActiveElement = document.activeElement;
  onDestroy(() => {
    previouslyActiveElement.focus();
  });
}
</script>

<svelte:window on:keydown={handleKeydown}/>

<div class="modal-background"
     role="presentation"
     style={zIndexStyle}
     on:mousedown|stopPropagation|preventDefault={() => false}
     on:mouseenter|stopPropagation|preventDefault={() => false}
     on:mouseleave|stopPropagation|preventDefault={() => false}
     on:mousemove|stopPropagation|preventDefault={() => false}
     on:mouseup|stopPropagation|preventDefault={() => false}
     on:click={close}
>
</div>
<!--svelte-ignore  a11y-no-noninteractive-element-interactions -->
<div class="modal"
     role="dialog" aria-modal="true"
     style={zIndexStyle}
     bind:this={modal}
     on:mousedown|stopPropagation|preventDefault={() => false}
     on:mouseenter|stopPropagation|preventDefault={() => false}
     on:mouseleave|stopPropagation|preventDefault={() => false}
     on:mousemove|stopPropagation|preventDefault={() => false}
     on:mouseup|stopPropagation|preventDefault={() => false}
>
    <TimePicker {options} {date}
                on:cancel={handleCancel}
                on:change
                on:ok={handleOK}
    />
</div>

<style>
    .modal-background {
        position: fixed;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background: rgba(0, 0, 0, 0.7);
    }

    .modal {
        box-shadow: 0 11px 15px -7px rgba(0, 0, 0, 0.2), 0 24px 38px 3px rgba(0, 0, 0, 0.14), 0 9px 46px 8px rgba(0, 0, 0, 0.12);
        left: 50%;
        overflow: auto;
        position: absolute;
        top: 50%;
        transform: translate(-50%, -50%);
    }
</style>
